@@ -155,10 +155,18 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                                             println!("Received: {:?}", message);
                                             match context_provider.new_context().await {
                                                 Ok(mut ctx) => {
-                                                    let processing_result = process_handler(&internal_ctx, &mut ctx, message.0).await;
-                                                    if processing_result.is_ok() {
-                                                        subscription.acknowledge_messages(vec![ack_id]).await;
+                                                    if !ctx.start_transaction().await.is_ok() {
+                                                        continue;
                                                     }
+                                                    let processing_result = process_handler(&internal_ctx, &mut ctx, message.0).await;
+                                                    if !processing_result.is_ok() {
+                                                        ctx.abort_transaction().await;
+                                                        continue;
+                                                    }
+                                                    if !ctx.commit_transaction().await.is_ok() {
+                                                        continue;
+                                                    }
+                                                    subscription.acknowledge_messages(vec![ack_id]).await;
                                                 }
                                                 Err(_) => {}
                                             }
